==> vido_toast-0.0.1.tar.gz: lib/src/vido_toast.dart <==
// Copyright (c) 2022, Very Good Ventures
// https://verygood.ventures
//
// Use of this source code is governed by an MIT-style
// license that can be found in the LICENSE file or at
// https://opensource.org/licenses/MIT.

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:oktoast/oktoast.dart';

/// {@template ToastWidget}
class ToastWidget extends StatelessWidget {
  const ToastWidget({super.key, required this.child, this.icon});

  final Widget child;
  final Widget? icon;

  @override
  Widget build(BuildContext context) {
    return Material(
      color: Colors.transparent,
      child: Row(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          Flexible(
            child: Container(
              margin: const EdgeInsets.symmetric(
                vertical: 24,
                horizontal: 24,
              ),
              padding: const EdgeInsets.symmetric(
                vertical: 12,
                horizontal: 20,
              ),
              constraints: const BoxConstraints(maxWidth: 450),
              decoration: BoxDecoration(
                color: Theme.of(context).cardColor,
                borderRadius: BorderRadius.circular(16),
                boxShadow: [
                  BoxShadow(
                    color: const Color(0xff000000).withOpacity(0.1),
                    blurRadius: 16,
                    spreadRadius: 8,
                  ),
                ],
              ),
              child: Row(
                mainAxisSize: MainAxisSize.min,
                children: [
                  if (icon != null) ...[
                    icon!,
                    const SizedBox(width: 12),
                  ],
                  Flexible(child: child),
                ],
              ),
            ),
          ),
        ],
      ),
    );
  }
}

/// {@template Toast}
class Toast {
  /// {@template Toast init}
  static Widget init(BuildContext context, Widget child) {
    return OKToast(child: child);
  }

  /// {@template Toast init}
  static void showWidget({required Widget child}) {
    showToastWidget(
      child,
      position: ToastPosition.bottom,
      duration: const Duration(milliseconds: 1500),
    );
  }

  /// {@template Toast init}
  static void show(String message) {
    showWidget(
      child: ToastWidget(
        icon: const Icon(
          CupertinoIcons.info_circle,
          color: Color(0xff407DE8),
        ),
        child: Text(
          message,
          textAlign: TextAlign.center,
          style: const TextStyle(color: Colors.black87),
        ),
      ),
    );
  }

  /// {@template Toast init}
  static void success(String message) {
    showWidget(
      child: ToastWidget(
        icon: const Icon(
          CupertinoIcons.checkmark_circle,
          color: Color(0xff2cae88),
        ),
        child: Text(
          message,
          textAlign: TextAlign.center,
          style: const TextStyle(color: Colors.black87),
        ),
      ),
    );
  }

  /// {@template Toast init}
  static void error(String message) {
    showWidget(
      child: ToastWidget(
        icon: const Icon(
          CupertinoIcons.exclamationmark_circle,
          color: Colors.red,
        ),
        child: Text(
          message,
          textAlign: TextAlign.center,
          style: const TextStyle(color: Colors.black87),
        ),
      ),
    );
  }
}

==> vido_toast-0.0.3.tar.gz: lib/src/vido_toast.dart <==
// Copyright (c) 2022, Very Good Ventures
// https://verygood.ventures
//
// Use of this source code is governed by an MIT-style
// license that can be found in the LICENSE file or at
// https://opensource.org/licenses/MIT.

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:oktoast/oktoast.dart';

/// {@template ToastWidget}
class ToastWidget extends StatelessWidget {
  /// {@template ToastWidget}
  const ToastWidget({super.key, required this.child, this.icon});

  /// {@template ToastWidget}
  final Widget child;

  /// {@template ToastWidget}
  final Widget? icon;

  @override
  Widget build(BuildContext context) {
    return Material(
      color: Colors.transparent,
      child: Row(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          Flexible(
            child: Container(
              margin: const EdgeInsets.symmetric(
                vertical: 24,
                horizontal: 24,
              ),
              padding: const EdgeInsets.symmetric(
                vertical: 12,
                horizontal: 20,
              ),
              constraints: const BoxConstraints(maxWidth: 450),
              decoration: BoxDecoration(
                color: Theme.of(context).cardColor,
                borderRadius: BorderRadius.circular(16),
                boxShadow: [
                  BoxShadow(
                    color: const Color(0xff000000).withOpacity(0.1),
                    blurRadius: 16,
                    spreadRadius: 8,
                  ),
                ],
              ),
              child: Row(
                mainAxisSize: MainAxisSize.min,
                children: [
                  if (icon != null) ...[
                    icon!,
                    const SizedBox(width: 12),
                  ],
                  Flexible(child: child),
                ],
              ),
            ),
          ),
        ],
      ),
    );
  }
}

/// {@template Toast}
class Toast {
  /// {@template Toast init}
  static Widget init(BuildContext context, Widget child) {
    return OKToast(child: child);
  }

  /// {@template Toast init}
  static void showWidget({
    required Widget child,
    Duration? duration,
    ToastPosition? position,
  }) {
    showToastWidget(
      child,
      position: position ?? ToastPosition.bottom,
      duration: duration ?? const Duration(milliseconds: 2000),
    );
  }

  /// {@template Toast show}
  static void show(
    String message, {
    Duration? duration,
    ToastPosition? position,
  }) {
    showWidget(
      duration: duration,
      position: position,
      child: ToastWidget(
        icon: const Icon(
          CupertinoIcons.info_circle,
          color: Color(0xff407DE8),
        ),
        child: Text(
          message,
          textAlign: TextAlign.center,
          style: const TextStyle(color: Colors.black87),
        ),
      ),
    );
  }

  /// {@template Toast success}
  static void success(
    String message, {
    Duration? duration,
    ToastPosition? position,
  }) {
    showWidget(
      duration: duration,
      position: position,
      child: ToastWidget(
        icon: const Icon(
          CupertinoIcons.checkmark_circle,
          color: Color(0xff2cae88),
        ),
        child: Text(
          message,
          textAlign: TextAlign.center,
          style: const TextStyle(color: Colors.black87),
        ),
      ),
    );
  }

  /// {@template Toast error}
  static void error(
    String message, {
    Duration? duration,
    ToastPosition? position,
  }) {
    showWidget(
      duration: duration ?? const Duration(milliseconds: 6000),
      position: position,
      child: ToastWidget(
        icon: const Icon(
          CupertinoIcons.exclamationmark_circle,
          color: Colors.red,
        ),
        child: Text(
          message,
          textAlign: TextAlign.center,
          style: const TextStyle(color: Colors.black87),
        ),
      ),
    );
  }

  /// {@template Toast dismissAllToast}
  static void hide() => dismissAllToast();
}
